==> estateplat-common-1.1.0-20170116.081648-248-sources.jar: cn/gtmap/estateplat/model/server/core/QllxParent.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 * 权利类型父类
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-3-18
 */
public class QllxParent implements Qllx,Serializable,QllxVo {
    @Id
    public String qlid;//权利主键
    public String proid;//项目主键
    public String bdcdyid;//不动产单元主键
    private String ywh;//业务号
    private Integer qszt;//权属状态 bdc_zd_qszt
    private String qllx;//权利类型
    private String dbr;//登簿人
    private Date djsj;//登簿时间
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间
    private String gyqk;//共有情况

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDbr() {
        return dbr;
    }

    @Override
    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    @Override
    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    @Override
    public String getFj() {
        return null;  //To change body of implemented methods use File | Settings | File Templates.
    }

    @Override
    public void setFj(String fj) {
        //To change body of implemented methods use File | Settings | File Templates.
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }
}

==> estateplat-common-1.2.3-20190513.145308-241-sources.jar: cn/gtmap/estateplat/model/server/core/QllxParent.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 * 权利类型父类
 *
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-3-18
 */
public class QllxParent implements Qllx,Serializable,QllxVo {
    @Id
    public String qlid;//权利主键
    public String proid;//项目主键
    public String bdcdyid;//不动产单元主键
    private String ywh;//业务号
    private Integer qszt;//权属状态 bdc_zd_qszt
    private String qllx;//权利类型
    private String dbr;//登簿人
    private Date djsj;//登簿时间
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间
    private String gyqk;//共有情况
    private String qlqtzk;//权利其他状况

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDbr() {
        return dbr;
    }

    @Override
    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    @Override
    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    @Override
    public String getFj() {
        return null;  //To change body of implemented methods use File | Settings | File Templates.
    }

    @Override
    public void setFj(String fj) {
        //To change body of implemented methods use File | Settings | File Templates.
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }
}
